==> dataspex-2025.06.2.jar: public/app/cljs-runtime/dataspex.views.js <==
goog.provide('dataspex.views');
dataspex.views.inline = new cljs.core.Keyword("dataspex.views","inline","dataspex.views/inline",446683124);
dataspex.views.dictionary = new cljs.core.Keyword("dataspex.views","dictionary","dataspex.views/dictionary",-1052047971);
dataspex.views.table = new cljs.core.Keyword("dataspex.views","table","dataspex.views/table",394751342);
dataspex.views.source = new cljs.core.Keyword("dataspex.views","source","dataspex.views/source",-1131308809);
dataspex.views.views = cljs.core.PersistentHashSet.createAsIfByAssoc([dataspex.views.inline,dataspex.views.table,dataspex.views.dictionary,dataspex.views.source]);
dataspex.views.max_items = (100);
dataspex.views.max_count = (1000);
dataspex.views.get_pagination = (function dataspex$views$get_pagination(p__81396){
var map__81397 = p__81396;
var map__81397__$1 = cljs.core.__destructure_map(map__81397);
var pagination = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__81397__$1,new cljs.core.Keyword("dataspex","pagination","dataspex/pagination",1579821342));
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__81397__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"page-size","page-size",223836073),(function (){var or__5002__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(pagination,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [path,new cljs.core.Keyword(null,"page-size","page-size",223836073)], null));
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
var or__5002__auto____$1 = new cljs.core.Keyword(null,"page-size","page-size",223836073).cljs$core$IFn$_invoke$arity$1(pagination);
if(cljs.core.truth_(or__5002__auto____$1)){
return or__5002__auto____$1;
} else {
return dataspex.views.max_items;
}
}
})(),new cljs.core.Keyword(null,"offset","offset",296498311),(function (){var or__5002__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(pagination,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [path,new cljs.core.Keyword(null,"offset","offset",296498311)], null));
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
return (0);
}
})()], null);
});
dataspex.views.offset_pagination = (function dataspex$views$offset_pagination(opt,n){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","pagination","dataspex/pagination",1579821342),new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword(null,"offset","offset",296498311)], null),n], null);
});
dataspex.views.update_folding = (function dataspex$views$update_folding(opt,path,v){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","folding","dataspex/folding",-1746748121),cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.vec(new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt)),path)], null),v], null);
});
dataspex.views.path_to = (function dataspex$views$path_to(var_args){
var G__81400 = arguments.length;
switch (G__81400) {
case 1:
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(dataspex.views.path_to.cljs$core$IFn$_invoke$arity$1 = (function (opt){
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2(opt,cljs.core.PersistentVector.EMPTY);
}));

(dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2 = (function (p__81401,xs){
var map__81402 = p__81401;
var map__81402__$1 = cljs.core.__destructure_map(map__81402);
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__81402__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.vec(path),xs);
}));

(dataspex.views.path_to.cljs$lang$maxFixedArity = 2);

dataspex.views.navigate_to = (function dataspex$views$navigate_to(opt,path){
var G__81404 = new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954)], null),path], null)], null);
if(cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword("dataspex.activity","browse","dataspex.activity/browse",121524428),new cljs.core.Keyword("dataspex","activity","dataspex/activity",252020907).cljs$core$IFn$_invoke$arity$1(opt))){
return cljs.core.conj.cljs$core$IFn$_invoke$arity$2(G__81404,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","activity","dataspex/activity",252020907)], null),new cljs.core.Keyword("dataspex.activity","browse","dataspex.activity/browse",121524428)], null));
} else {
return G__81404;
}
});
dataspex.views.get_current_view = (function dataspex$views$get_current_view(v,p__81405){
var map__81406 = p__81405;
var map__81406__$1 = cljs.core.__destructure_map(map__81406);
var opt = map__81406__$1;
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__81406__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
var view = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__81406__$1,new cljs.core.Keyword("dataspex","view","dataspex/view",-1507071672));
var default_view = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__81406__$1,new cljs.core.Keyword("dataspex","default-view","dataspex/default-view",2016721560));
var or__5002__auto__ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(view,path);
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
var or__5002__auto____$1 = (((((!((v == null))))?((((false) || ((cljs.core.PROTOCOL_SENTINEL === v.dataspex$protocols$IPrefersView$))))?true:(((!v.cljs$lang$protocol_mask$partition$))?cljs.core.native_satisfies_QMARK_(dataspex.protocols.IPrefersView,v):false)):cljs.core.native_satisfies_QMARK_(dataspex.protocols.IPrefersView,v)))?(function (){var G__81408 = dataspex.protocols.get_preferred_view(v);
return (dataspex.views.views.cljs$core$IFn$_invoke$arity$1 ? dataspex.views.views.cljs$core$IFn$_invoke$arity$1(G__81408) : dataspex.views.views.call(null,G__81408));
})():null);
if(cljs.core.truth_(or__5002__auto____$1)){
return or__5002__auto____$1;
} else {
var or__5002__auto____$2 = (cljs.core.truth_(dataspex.data.supports_view_QMARK_(v,default_view,opt))?default_view:null);
if(cljs.core.truth_(or__5002__auto____$2)){
return or__5002__auto____$2;
} else {
var or__5002__auto____$3 = (cljs.core.truth_(dataspex.data.hiccup_QMARK_(v))?dataspex.views.source:null);
if(cljs.core.truth_(or__5002__auto____$3)){
return or__5002__auto____$3;
} else {
return dataspex.views.dictionary;
}
}
}
}
});
dataspex.views.get_render_data = (function dataspex$views$get_render_data(state,inspectee){
var inspector_state = cljs.core.get.cljs$core$IFn$_invoke$arity$2(state,inspectee);
var opt = cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677),inspectee], null),cljs.core.select_keys(inspector_state,cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.comp.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 1, ["dataspex",null], null), null),cljs.core.namespace),cljs.core.keys(inspector_state)))], 0));
var data = dataspex.data.nav_in(cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(state,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [inspectee,new cljs.core.Keyword(null,"val","val",128701612)], null)),new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt));
var opt__$1 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(opt,new cljs.core.Keyword("dataspex","view","dataspex/view",-1507071672),dataspex.views.get_current_view(data,opt));
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"opt","opt",-794706369),opt__$1,new cljs.core.Keyword(null,"data","data",-232669377),dataspex.data.inspect.cljs$core$IFn$_invoke$arity$2(data,opt__$1)], null);
});

//# sourceMappingURL=dataspex.views.js.map

==> dataspex-2025.06.4.jar: public/app/cljs-runtime/dataspex.views.js <==
goog.provide('dataspex.views');
dataspex.views.inline = new cljs.core.Keyword("dataspex.views","inline","dataspex.views/inline",446683124);
dataspex.views.dictionary = new cljs.core.Keyword("dataspex.views","dictionary","dataspex.views/dictionary",-1052047971);
dataspex.views.table = new cljs.core.Keyword("dataspex.views","table","dataspex.views/table",394751342);
dataspex.views.source = new cljs.core.Keyword("dataspex.views","source","dataspex.views/source",-1131308809);
dataspex.views.views = cljs.core.PersistentHashSet.createAsIfByAssoc([dataspex.views.inline,dataspex.views.table,dataspex.views.dictionary,dataspex.views.source]);
dataspex.views.max_items = (100);
dataspex.views.max_count = (1000);
dataspex.views.get_pagination = (function dataspex$views$get_pagination(p__45806){
var map__45807 = p__45806;
var map__45807__$1 = cljs.core.__destructure_map(map__45807);
var pagination = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__45807__$1,new cljs.core.Keyword("dataspex","pagination","dataspex/pagination",1579821342));
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__45807__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"page-size","page-size",223836073),(function (){var or__5002__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(pagination,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [path,new cljs.core.Keyword(null,"page-size","page-size",223836073)], null));
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
var or__5002__auto____$1 = new cljs.core.Keyword(null,"page-size","page-size",223836073).cljs$core$IFn$_invoke$arity$1(pagination);
if(cljs.core.truth_(or__5002__auto____$1)){
return or__5002__auto____$1;
} else {
return dataspex.views.max_items;
}
}
})(),new cljs.core.Keyword(null,"offset","offset",296498311),(function (){var or__5002__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(pagination,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [path,new cljs.core.Keyword(null,"offset","offset",296498311)], null));
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
return (0);
}
})()], null);
});
dataspex.views.offset_pagination = (function dataspex$views$offset_pagination(opt,n){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","pagination","dataspex/pagination",1579821342),new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword(null,"offset","offset",296498311)], null),n], null);
});
dataspex.views.update_folding = (function dataspex$views$update_folding(opt,path,v){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","folding","dataspex/folding",-1746748121),cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.vec(new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt)),path)], null),v], null);
});
dataspex.views.path_to = (function dataspex$views$path_to(var_args){
var G__45817 = arguments.length;
switch (G__45817) {
case 1:
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(dataspex.views.path_to.cljs$core$IFn$_invoke$arity$1 = (function (opt){
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2(opt,cljs.core.PersistentVector.EMPTY);
}));

(dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2 = (function (p__45826,xs){
var map__45827 = p__45826;
var map__45827__$1 = cljs.core.__destructure_map(map__45827);
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__45827__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.vec(path),xs);
}));

(dataspex.views.path_to.cljs$lang$maxFixedArity = 2);

dataspex.views.navigate_to = (function dataspex$views$navigate_to(opt,path){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","navigate","dataspex.actions/navigate",1833982734),new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),path], null)], null);
});
dataspex.views.get_current_view = (function dataspex$views$get_current_view(v,p__45835){
var map__45836 = p__45835;
var map__45836__$1 = cljs.core.__destructure_map(map__45836);
var opt = map__45836__$1;
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__45836__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
var view = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__45836__$1,new cljs.core.Keyword("dataspex","view","dataspex/view",-1507071672));
var default_view = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__45836__$1,new cljs.core.Keyword("dataspex","default-view","dataspex/default-view",2016721560));
var or__5002__auto__ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(view,path);
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
var or__5002__auto____$1 = (((((!((v == null))))?((((false) || ((cljs.core.PROTOCOL_SENTINEL === v.dataspex$protocols$IPrefersView$))))?true:(((!v.cljs$lang$protocol_mask$partition$))?cljs.core.native_satisfies_QMARK_(dataspex.protocols.IPrefersView,v):false)):cljs.core.native_satisfies_QMARK_(dataspex.protocols.IPrefersView,v)))?(function (){var G__45839 = dataspex.protocols.get_preferred_view(v);
return (dataspex.views.views.cljs$core$IFn$_invoke$arity$1 ? dataspex.views.views.cljs$core$IFn$_invoke$arity$1(G__45839) : dataspex.views.views.call(null,G__45839));
})():null);
if(cljs.core.truth_(or__5002__auto____$1)){
return or__5002__auto____$1;
} else {
var or__5002__auto____$2 = (cljs.core.truth_(dataspex.data.supports_view_QMARK_(v,default_view,opt))?default_view:null);
if(cljs.core.truth_(or__5002__auto____$2)){
return or__5002__auto____$2;
} else {
var or__5002__auto____$3 = (cljs.core.truth_(dataspex.data.hiccup_QMARK_(v))?dataspex.views.source:null);
if(cljs.core.truth_(or__5002__auto____$3)){
return or__5002__auto____$3;
} else {
return dataspex.views.dictionary;
}
}
}
}
});
dataspex.views.get_render_data = (function dataspex$views$get_render_data(state,inspectee){
var inspector_state = cljs.core.get.cljs$core$IFn$_invoke$arity$2(state,inspectee);
var opt = cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677),inspectee], null),cljs.core.select_keys(inspector_state,cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.comp.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 1, ["dataspex",null], null), null),cljs.core.namespace),cljs.core.keys(inspector_state)))], 0));
var data = dataspex.data.nav_in(cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(state,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [inspectee,new cljs.core.Keyword(null,"val","val",128701612)], null)),new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt));
var opt__$1 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(opt,new cljs.core.Keyword("dataspex","view","dataspex/view",-1507071672),dataspex.views.get_current_view(data,opt));
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"opt","opt",-794706369),opt__$1,new cljs.core.Keyword(null,"data","data",-232669377),dataspex.data.inspect.cljs$core$IFn$_invoke$arity$2(data,opt__$1)], null);
});

//# sourceMappingURL=dataspex.views.js.map
